==> xpojo-1.0.0-src.zip: ExcelPOJO Version 1.0.0/TestSource/test/annotation/ColumnInfo.java <==
package test.annotation;

import net.w_horse.excelpojo.annotation.LabeledCell;

public class ColumnInfo {

	public ColumnInfo() {
	}

	public String toString() {
		StringBuffer sBuff = new StringBuffer();
		sBuff.append("e[uF" + tableName);
		sBuff.append("(" + String.valueOf(columnId) + ")");

		sBuff.append( "[ColumnName=" + String.valueOf(columnName) + "]");
		sBuff.append( "[ColumnNameKnj=" + String.valueOf(columnNameKnj) + "]");
		sBuff.append( "[ColumnAttr=" + String.valueOf(columnAttr) + "]");
		sBuff.append( "[ColumnLength=" + String.valueOf(columnLength) + "]");
		sBuff.append( "[FloatingPos=" + String.valueOf(floatingPos) + "]");
		sBuff.append( "[PrimaryKeyNo=" + String.valueOf(primaryKeyNo) + "]");
		sBuff.append( "[Nullable=" + nullable + "]");
		sBuff.append( "[InitialValue=" + InitialValue + "]");

		return sBuff.toString();
	}

//	------------------------------< ϐݒ >
	private String tableName = "";
	@LabeledCell(label="mn")
	private int columnId = 0;
	@LabeledCell(label="ڋL")
	private String columnName = "";
	@LabeledCell(label="ږ")
	private String columnNameKnj = "";
	@LabeledCell(label="f[^^")
	private String columnAttr = "";
	@LabeledCell(label="oCg")
	private int columnLength = 0;
	@LabeledCell(label="")
	private int floatingPos = 0;
	@LabeledCell(label="L[")
	private int primaryKeyNo = 0;
	@LabeledCell(label="OPTION")
	private String nullable = "";
	private String InitialValue = "";

//	------------------------------< setter` >
	public void setTableName(String sVal){ this.tableName=sVal; }
	public void setColumnId(int sVal){ this.columnId=sVal; }
	public void setColumnName(String sVal){ this.columnName=sVal; }
	public void setColumnNameKnj(String sVal){ this.columnNameKnj=sVal; }
	public void setColumnAttr(String sVal){ this.columnAttr=sVal; }
	public void setColumnLength(int sVal){ this.columnLength=sVal; }
	public void setFloatingPos(int sVal){ this.floatingPos=sVal; }
	public void setPrimaryKeyNo(int sVal){ this.primaryKeyNo=sVal; }
	public void setNullable(String sVal){ this.nullable=sVal; }
	public void setInitialValue(String sVal){ this.InitialValue=sVal; }

//	------------------------------< getter` >
	public String getTableName(){ return this.tableName; }
	public int getColumnId(){ return this.columnId; }
	public String getColumnName(){ return this.columnName; }
	public String getColumnNameKnj(){ return this.columnNameKnj; }
	public String getColumnAttr(){ return this.columnAttr; }
	public int getColumnLength(){ return this.columnLength; }
	public int getFloatingPos(){ return this.floatingPos; }
	public int getPrimaryKeyNo(){ return this.primaryKeyNo; }
	public String getNullable(){ return this.nullable; }
	public String getInitialValue(){ return this.InitialValue; }


}

==> xpojo-1.1.2-src.zip: ExcelPOJO Version 1.1.2/TestSource/test/annotation/ColumnInfo.java <==
package test.annotation;

import net.w_horse.excelpojo.annotation.LabeledCell;

public class ColumnInfo {

	public ColumnInfo() {
	}

	public String toString() {
		StringBuffer sBuff = new StringBuffer();
		sBuff.append("e[uF" + tableName);
		sBuff.append("(" + String.valueOf(columnId) + ")");

		sBuff.append( "[ColumnName=" + String.valueOf(columnName) + "]");
		sBuff.append( "[ColumnNameKnj=" + String.valueOf(columnNameKnj) + "]");
		sBuff.append( "[ColumnAttr=" + String.valueOf(columnAttr) + "]");
		sBuff.append( "[ColumnLength=" + String.valueOf(columnLength) + "]");
		sBuff.append( "[FloatingPos=" + String.valueOf(floatingPos) + "]");
		sBuff.append( "[PrimaryKeyNo=" + String.valueOf(primaryKeyNo) + "]");
		sBuff.append( "[Nullable=" + nullable + "]");
		sBuff.append( "[InitialValue=" + InitialValue + "]");

		return sBuff.toString();
	}

//	------------------------------< ϐݒ >
	private String tableName = "";
	@LabeledCell(label="mn")
	private int columnId = 0;
	@LabeledCell(label="ڋL")
	private String columnName = "";
	@LabeledCell(label="ږ")
	private String columnNameKnj = "";
	@LabeledCell(label="f[^^")
	private String columnAttr = "";
	@LabeledCell(label="oCg")
	private int columnLength = 0;
	@LabeledCell(label="")
	private int floatingPos = 0;
	@LabeledCell(label="L[")
	private int primaryKeyNo = 0;
	@LabeledCell(label="OPTION")
	private String nullable = "";
	private String InitialValue = "";

	private String comcrtYMD;
	private String comcrtShainCod;
	private String comupdYMD;
	private String comupdShainCod;

//	------------------------------< setter` >
	public void setTableName(String sVal){ this.tableName=sVal; }
	public void setColumnId(int sVal){ this.columnId=sVal; }
	public void setColumnName(String sVal){ this.columnName=sVal; }
	public void setColumnNameKnj(String sVal){ this.columnNameKnj=sVal; }
	public void setColumnAttr(String sVal){ this.columnAttr=sVal; }
	public void setColumnLength(int sVal){ this.columnLength=sVal; }
	public void setFloatingPos(int sVal){ this.floatingPos=sVal; }
	public void setPrimaryKeyNo(int sVal){ this.primaryKeyNo=sVal; }
	public void setNullable(String sVal){ this.nullable=sVal; }
	public void setInitialValue(String sVal){ this.InitialValue=sVal; }

	public void setComcrtYMD(String sVal){ this.comcrtYMD=sVal; }
	public void setComcrtShainCod(String sVal){ this.comcrtShainCod=sVal; }
	public void setComupdYMD(String sVal){ this.comupdYMD=sVal; }
	public void setComupdShainCod(String sVal){ this.comupdShainCod=sVal; }

//	------------------------------< getter` >
	public String getTableName(){ return this.tableName; }
	public int getColumnId(){ return this.columnId; }
	public String getColumnName(){ return this.columnName; }
	public String getColumnNameKnj(){ return this.columnNameKnj; }
	public String getColumnAttr(){ return this.columnAttr; }
	public int getColumnLength(){ return this.columnLength; }
	public int getFloatingPos(){ return this.floatingPos; }
	public int getPrimaryKeyNo(){ return this.primaryKeyNo; }
	public String getNullable(){ return this.nullable; }
	public String getInitialValue(){ return this.InitialValue; }

	public String getComcrtYMD(){ return this.comcrtYMD; }
	public String getComcrtShainCod(){ return this.comcrtShainCod; }
	public String getComupdYMD(){ return this.comupdYMD; }
	public String getComupdShainCod(){ return this.comupdShainCod; }


}
